@@ -1,11 +1,9 @@
 import errno
-
-from dvc.utils.compat import FileNotFoundError, urlparse
-
 import itertools
 import json
 import logging
 import tempfile
+from urllib.parse import urlparse
 from concurrent.futures import ThreadPoolExecutor
 from copy import copy
 from functools import partial
@@ -26,8 +24,8 @@ from dvc.path_info import PathInfo, URLInfo
 from dvc.progress import Tqdm
 from dvc.remote.slow_link_detection import slow_link_guard
 from dvc.state import StateNoop
-from dvc.utils import makedirs, relpath, tmp_fname
-from dvc.utils.fs import move
+from dvc.utils import relpath, tmp_fname
+from dvc.utils.fs import move, makedirs
 from dvc.utils.http import open_url
 
 logger = logging.getLogger(__name__)
@@ -48,7 +46,7 @@ STATUS_MAP = {
 
 class RemoteCmdError(DvcException):
     def __init__(self, remote, cmd, ret, err):
-        super(RemoteCmdError, self).__init__(
+        super().__init__(
             "{remote} command '{cmd}' finished with non-zero return code"
             " {ret}': {err}".format(remote=remote, cmd=cmd, ret=ret, err=err)
         )
@@ -57,7 +55,7 @@ class RemoteCmdError(DvcException):
 class RemoteActionNotImplemented(DvcException):
     def __init__(self, action, scheme):
         m = "{} is not supported for {} remotes".format(action, scheme)
-        super(RemoteActionNotImplemented, self).__init__(m)
+        super().__init__(m)
 
 
 class RemoteMissingDepsError(DvcException):
@@ -65,10 +63,9 @@ class RemoteMissingDepsError(DvcException):
 
 
 class DirCacheError(DvcException):
-    def __init__(self, checksum, cause=None):
-        super(DirCacheError, self).__init__(
-            "Failed to load dir cache for checksum: '{}'.".format(checksum),
-            cause=cause,
+    def __init__(self, checksum):
+        super().__init__(
+            "Failed to load dir cache for checksum: '{}'.".format(checksum)
         )
 
 
@@ -266,7 +263,7 @@ class RemoteBASE(object):
             with self.cache.open(path_info, "r") as fobj:
                 d = json.load(fobj)
         except (ValueError, FileNotFoundError) as exc:
-            raise DirCacheError(checksum, cause=exc)
+            raise DirCacheError(checksum) from exc
 
         if not isinstance(d, list):
             msg = "dir cache file format error '{}' [skipping the file]"
@@ -700,6 +697,8 @@ class RemoteBASE(object):
             if checksum in used:
                 continue
             path_info = self.checksum_to_path_info(checksum)
+            if self.is_dir_checksum(checksum):
+                self._remove_unpacked_dir(checksum)
             self.remove(path_info)
             removed = True
         return removed
@@ -1012,3 +1011,6 @@ class RemoteBASE(object):
 
     def _update_unpacked_dir(self, checksum):
         pass
+
+    def _remove_unpacked_dir(self, checksum):
+        pass
