@@ -2,6 +2,7 @@ import os
 import posixpath
 import logging
 import threading
+import re
 
 from funcy import retry, compose, decorator, wrap_with
 from funcy.py3 import cat
@@ -19,18 +20,15 @@ FOLDER_MIME_TYPE = "application/vnd.google-apps.folder"
 
 
 class GDriveRetriableError(DvcException):
-    def __init__(self, msg, cause=None):
-        super(GDriveRetriableError, self).__init__(msg, cause=cause)
+    pass
 
 
 class GDriveAccessTokenRefreshError(DvcException):
-    def __init__(self, msg, cause=None):
-        super(GDriveAccessTokenRefreshError, self).__init__(msg, cause=cause)
+    pass
 
 
 class GDriveMissedCredentialKeyError(DvcException):
-    def __init__(self, msg, cause=None):
-        super(GDriveMissedCredentialKeyError, self).__init__(msg, cause=cause)
+    pass
 
 
 @decorator
@@ -68,9 +66,19 @@ class RemoteGDrive(RemoteBASE):
     DEFAULT_USER_CREDENTIALS_FILE = "gdrive-user-credentials.json"
 
     def __init__(self, repo, config):
-        super(RemoteGDrive, self).__init__(repo, config)
+        super().__init__(repo, config)
         self.no_traverse = False
         self.path_info = self.path_cls(config[Config.SECTION_REMOTE_URL])
+
+        bucket = re.search(
+            "{}://(.*)".format(self.scheme),
+            config[Config.SECTION_REMOTE_URL],
+            re.IGNORECASE,
+        )
+        self.bucket = (
+            bucket.group(1).split("/")[0] if bucket else self.path_info.bucket
+        )
+
         self.config = config
         self.init_drive()
 
@@ -147,7 +155,7 @@ class RemoteGDrive(RemoteBASE):
         cached_dirs = {}
         cached_ids = {}
         for dir1 in self.gdrive_list_item(
-            "'{}' in parents and trashed=false".format(self.root_id)
+            "'{}' in parents and trashed=false".format(self.remote_root_id)
         ):
             remote_path = posixpath.join(self.path_info.path, dir1["title"])
             cached_dirs.setdefault(remote_path, []).append(dir1["id"])
@@ -208,28 +216,31 @@ class RemoteGDrive(RemoteBASE):
 
             try:
                 gauth.CommandLineAuth()
-            except RefreshError as e:
+            except RefreshError as exc:
                 raise GDriveAccessTokenRefreshError(
-                    "Google Drive's access token refreshment is failed", e
-                )
-            except KeyError as e:
+                    "Google Drive's access token refreshment is failed"
+                ) from exc
+            except KeyError as exc:
                 raise GDriveMissedCredentialKeyError(
                     "Google Drive's user credentials file '{}' "
                     "misses value for key '{}'".format(
-                        self.gdrive_user_credentials_path, str(e)
-                    ),
-                    e,
+                        self.gdrive_user_credentials_path, str(exc)
+                    )
                 )
             # Handle pydrive.auth.AuthenticationError and others auth failures
-            except Exception as e:
-                raise DvcException("Google Drive authentication failed", e)
+            except Exception as exc:
+                raise DvcException(
+                    "Google Drive authentication failed"
+                ) from exc
             finally:
                 if os.getenv(RemoteGDrive.GDRIVE_USER_CREDENTIALS_DATA):
                     os.remove(self.gdrive_user_credentials_path)
 
             self._gdrive = GoogleDrive(gauth)
 
-            self.root_id = self.get_remote_id(self.path_info, create=True)
+            self.remote_root_id = self.get_remote_id(
+                self.path_info, create=True
+            )
             self._cached_dirs, self._cached_ids = self.cache_root_dirs()
 
         return self._gdrive
@@ -263,7 +274,7 @@ class RemoteGDrive(RemoteBASE):
         return next(iter(item_list), None)
 
     def resolve_remote_item_from_path(self, path_parts, create):
-        parents_ids = ["root"]
+        parents_ids = [self.bucket]
         current_path = ""
         for path_part in path_parts:
             current_path = posixpath.join(current_path, path_part)
