@@ -5,9 +5,9 @@ from functools import wraps
 from itertools import chain
 
 from dvc.ignore import CleanTree
-from dvc.utils.compat import FileNotFoundError, fspath_py35, open as _open
+from dvc.compat import fspath_py35
 
-from funcy import cached_property
+from funcy import cached_property, cat
 
 from dvc.config import Config
 from dvc.exceptions import (
@@ -72,7 +72,7 @@ class Repo(object):
         from dvc.repo.metrics import Metrics
         from dvc.scm.tree import WorkingTree
         from dvc.repo.tag import Tag
-        from dvc.utils import makedirs
+        from dvc.utils.fs import makedirs
 
         root_dir = self.find_root(root_dir)
 
@@ -83,7 +83,7 @@ class Repo(object):
 
         self.scm = SCM(self.root_dir)
 
-        self.tree = CleanTree(WorkingTree(self.root_dir))
+        self.tree = WorkingTree(self.root_dir)
 
         self.tmp_dir = os.path.join(self.dvc_dir, "tmp")
         makedirs(self.tmp_dir, exist_ok=True)
@@ -120,7 +120,7 @@ class Repo(object):
 
     @tree.setter
     def tree(self, tree):
-        self._tree = tree
+        self._tree = tree if isinstance(tree, CleanTree) else CleanTree(tree)
         # Our graph cache is no longer valid, as it was based on the previous
         # tree.
         self._reset()
@@ -238,7 +238,6 @@ class Repo(object):
             A dictionary with Schemes (representing output's location) as keys,
             and a list with the outputs' `dumpd` as values.
         """
-        from funcy.py2 import icat
         from dvc.cache import NamedCache
 
         cache = NamedCache()
@@ -250,7 +249,7 @@ class Repo(object):
         ):
             targets = targets or [None]
 
-            pairs = icat(
+            pairs = cat(
                 self.collect_granular(
                     target, recursive=recursive, with_deps=with_deps
                 )
@@ -363,17 +362,6 @@ class Repo(object):
     def pipelines(self):
         return get_pipelines(self.graph)
 
-    @staticmethod
-    def _filter_out_dirs(dirs, outs, root_dir):
-        def filter_dirs(dname):
-            path = os.path.join(root_dir, dname)
-            for out in outs:
-                if path == os.path.normpath(out):
-                    return False
-            return True
-
-        return list(filter(filter_dirs, dirs))
-
     @cached_property
     def stages(self):
         """
@@ -388,7 +376,7 @@ class Repo(object):
         from dvc.stage import Stage
 
         stages = []
-        outs = []
+        outs = set()
 
         for root, dirs, files in self.tree.walk(self.root_dir):
             for fname in files:
@@ -396,12 +384,13 @@ class Repo(object):
                 if not Stage.is_valid_filename(path):
                     continue
                 stage = Stage.load(self, path)
-                for out in stage.outs:
-                    if out.scheme == "local":
-                        outs.append(out.fspath + out.sep)
                 stages.append(stage)
 
-            dirs[:] = self._filter_out_dirs(dirs, outs, root)
+                for out in stage.outs:
+                    if out.scheme == "local":
+                        outs.add(out.fspath)
+
+            dirs[:] = [d for d in dirs if os.path.join(root, d) not in outs]
 
         return stages
 
@@ -444,24 +433,24 @@ class Repo(object):
         cause = None
         try:
             out, = self.find_outs_by_path(path)
-        except OutputNotFoundError as e:
+        except OutputNotFoundError as exc:
             out = None
-            cause = e
+            cause = exc
 
         if out and out.use_cache:
             try:
                 with self._open_cached(out, remote, mode, encoding) as fd:
                     yield fd
                 return
-            except FileNotFoundError as e:
-                raise FileMissingError(relpath(path, self.root_dir), cause=e)
+            except FileNotFoundError as exc:
+                raise FileMissingError(relpath(path, self.root_dir)) from exc
 
         if self.tree.exists(path):
             with self.tree.open(path, mode, encoding) as fd:
                 yield fd
             return
 
-        raise FileMissingError(relpath(path, self.root_dir), cause=cause)
+        raise FileMissingError(relpath(path, self.root_dir)) from cause
 
     def _open_cached(self, out, remote=None, mode="r", encoding=None):
         if out.isdir():
@@ -471,7 +460,7 @@ class Repo(object):
         cache_file = fspath_py35(cache_file)
 
         if os.path.exists(cache_file):
-            return _open(cache_file, mode=mode, encoding=encoding)
+            return open(cache_file, mode=mode, encoding=encoding)
 
         try:
             remote_obj = self.cloud.get_remote(remote)
@@ -482,7 +471,7 @@ class Repo(object):
                 cache_info = out.get_used_cache(remote=remote)
                 self.cloud.pull(cache_info, remote=remote)
 
-            return _open(cache_file, mode=mode, encoding=encoding)
+            return open(cache_file, mode=mode, encoding=encoding)
 
     def close(self):
         self.scm.close()
