@@ -10,8 +10,6 @@ from jsonpath_ng.ext import parse
 from dvc.exceptions import NoMetricsError
 from dvc.exceptions import OutputNotFoundError
 from dvc.repo import locked
-from dvc.utils.compat import csv_reader
-from dvc.utils.compat import open
 
 NO_METRICS_FILE_AT_REFERENCE_WARNING = (
     "Metrics file '{}' does not exist at the reference '{}'."
@@ -101,7 +99,7 @@ def _format_csv(content, delimiter):
         "0.67528    0.289545        testing\n"
         "0.671502   0.297848        validation\n"
     """
-    reader = csv_reader(io.StringIO(content), delimiter=delimiter)
+    reader = csv.reader(io.StringIO(content), delimiter=delimiter)
     rows = [row for row in reader]
     max_widths = [max(map(len, column)) for column in zip(*rows)]
 
@@ -295,6 +293,15 @@ def show(
     if not res and not any(targets):
         raise NoMetricsError()
 
+    # Hide working tree metrics if they are the same as in the active branch
+    try:
+        active_branch = repo.scm.active_branch()
+    except TypeError:
+        pass  # Detached head
+    else:
+        if res.get("working tree") == res.get(active_branch):
+            res.pop("working tree", None)
+
     missing = set(targets) - found
 
     if missing:
