@@ -9,12 +9,6 @@ from funcy.py3 import lmap, lfilter, lmapcat
 
 from .exceptions import DvcException
 from .lock import LockError
-from .utils.compat import (
-    convert_to_unicode,
-    FileNotFoundError,
-    JSONDecodeError,
-    str,
-)
 from .utils.fs import relpath
 
 INFO_SCHEMA = {"pid": int, "cmd": str}
@@ -23,18 +17,17 @@ SCHEMA = Schema({"write": {str: INFO_SCHEMA}, "read": {str: [INFO_SCHEMA]}})
 
 
 class RWLockFileCorruptedError(DvcException):
-    def __init__(self, path, cause):
-        super(RWLockFileCorruptedError, self).__init__(
+    def __init__(self, path):
+        super().__init__(
             "Unable to read RWLock-file '{}'. JSON structure is "
-            "corrupted".format(relpath(path)),
-            cause=cause,
+            "corrupted".format(relpath(path))
         )
 
 
 class RWLockFileFormatError(DvcException):
-    def __init__(self, path, cause):
-        super(RWLockFileFormatError, self).__init__(
-            "RWLock-file '{}' format error.".format(relpath(path)), cause=cause
+    def __init__(self, path):
+        super().__init__(
+            "RWLock-file '{}' format error.".format(relpath(path))
         )
 
 
@@ -44,19 +37,22 @@ def _edit_rwlock(lock_dir):
     try:
         with open(path, "r") as fobj:
             lock = json.load(fobj)
-        lock = SCHEMA(convert_to_unicode(lock))
+        lock = SCHEMA(lock)
     except FileNotFoundError:
         lock = SCHEMA({})
-    except JSONDecodeError as exc:
-        raise RWLockFileCorruptedError(path, cause=exc)
+    except json.JSONDecodeError as exc:
+        raise RWLockFileCorruptedError(path) from exc
     except Invalid as exc:
-        raise RWLockFileFormatError(path, cause=exc)
+        raise RWLockFileFormatError(path) from exc
     lock = defaultdict(dict, lock)
     lock["read"] = defaultdict(list, lock["read"])
     lock["write"] = defaultdict(dict, lock["write"])
     yield lock
     with open(path, "w+") as fobj:
         json.dump(lock, fobj)
+        # NOTE: flush and fsync to ensure that rwlock contents are saved
+        fobj.flush()
+        os.fsync(fobj.fileno())
 
 
 def _infos_to_str(infos):
