@@ -1,4 +1,4 @@
-from dvc.utils.compat import pathlib
+import pathlib
 import logging
 import os
 import re
@@ -33,13 +33,13 @@ logger = logging.getLogger(__name__)
 class StageCmdFailedError(DvcException):
     def __init__(self, stage):
         msg = "stage '{}' cmd '{}' failed".format(stage.relpath, stage.cmd)
-        super(StageCmdFailedError, self).__init__(msg)
+        super().__init__(msg)
 
 
 class StageFileFormatError(DvcException):
     def __init__(self, fname, e):
         msg = "DVC-file '{}' format error: {}".format(fname, str(e))
-        super(StageFileFormatError, self).__init__(msg)
+        super().__init__(msg)
 
 
 class StageFileDoesNotExistError(DvcException):
@@ -50,13 +50,13 @@ class StageFileDoesNotExistError(DvcException):
         if Stage.is_stage_file(sname):
             msg += " Do you mean '{}'?".format(sname)
 
-        super(StageFileDoesNotExistError, self).__init__(msg)
+        super().__init__(msg)
 
 
 class StageFileAlreadyExistsError(DvcException):
     def __init__(self, relpath):
         msg = "stage '{}' already exists".format(relpath)
-        super(StageFileAlreadyExistsError, self).__init__(msg)
+        super().__init__(msg)
 
 
 class StageFileIsNotDvcFileError(DvcException):
@@ -67,30 +67,29 @@ class StageFileIsNotDvcFileError(DvcException):
         if Stage.is_stage_file(sname):
             msg += " Do you mean '{}'?".format(sname)
 
-        super(StageFileIsNotDvcFileError, self).__init__(msg)
+        super().__init__(msg)
 
 
 class StageFileBadNameError(DvcException):
-    def __init__(self, msg):
-        super(StageFileBadNameError, self).__init__(msg)
+    pass
 
 
 class StagePathOutsideError(DvcException):
     def __init__(self, path):
         msg = "stage working or file path '{}' is outside of dvc repo"
-        super(StagePathOutsideError, self).__init__(msg.format(path))
+        super().__init__(msg.format(path))
 
 
 class StagePathNotFoundError(DvcException):
     def __init__(self, path):
         msg = "stage working or file path '{}' does not exist"
-        super(StagePathNotFoundError, self).__init__(msg.format(path))
+        super().__init__(msg.format(path))
 
 
 class StagePathNotDirectoryError(DvcException):
     def __init__(self, path):
         msg = "stage working or file path '{}' is not directory"
-        super(StagePathNotDirectoryError, self).__init__(msg.format(path))
+        super().__init__(msg.format(path))
 
 
 class StageCommitError(DvcException):
@@ -99,7 +98,7 @@ class StageCommitError(DvcException):
 
 class StageUpdateError(DvcException):
     def __init__(self, path):
-        super(StageUpdateError, self).__init__(
+        super().__init__(
             "update is not supported for '{}' that is not an "
             "import.".format(path)
         )
@@ -115,7 +114,7 @@ class MissingDep(DvcException):
             dep = "dependency"
 
         msg = "missing '{}': {}".format(dep, ", ".join(map(str, deps)))
-        super(MissingDep, self).__init__(msg)
+        super().__init__(msg)
 
 
 class MissingDataSource(DvcException):
@@ -127,7 +126,7 @@ class MissingDataSource(DvcException):
             source += "s"
 
         msg = "missing data '{}': {}".format(source, ", ".join(missing_files))
-        super(MissingDataSource, self).__init__(msg)
+        super().__init__(msg)
 
 
 @decorator
@@ -144,6 +143,8 @@ def rwlocked(call, read=None, write=None):
 
     stage = call._args[0]
 
+    assert stage.repo.lock.is_locked
+
     def _chain(names):
         return [
             item.path_info
@@ -265,10 +266,7 @@ class Stage(object):
     @staticmethod
     def is_valid_filename(path):
         return (
-            # path.endswith doesn't work for encoded unicode filenames on
-            # Python 2 and since Stage.STAGE_FILE_SUFFIX is ascii then it is
-            # not needed to decode the path from py2's str
-            path[-len(Stage.STAGE_FILE_SUFFIX) :] == Stage.STAGE_FILE_SUFFIX
+            path.endswith(Stage.STAGE_FILE_SUFFIX)
             or os.path.basename(path) == Stage.STAGE_FILE
         )
 
@@ -421,10 +419,8 @@ class Stage(object):
 
     @staticmethod
     def validate(d, fname=None):
-        from dvc.utils.compat import convert_to_unicode
-
         try:
-            Stage.COMPILED_SCHEMA(convert_to_unicode(d))
+            Stage.COMPILED_SCHEMA(d)
         except MultipleInvalid as exc:
             raise StageFileFormatError(fname, exc)
 
@@ -698,8 +694,10 @@ class Stage(object):
             stage_text=stage_text,
         )
 
-        stage.deps = dependency.loadd_from(stage, d.get(Stage.PARAM_DEPS, []))
-        stage.outs = output.loadd_from(stage, d.get(Stage.PARAM_OUTS, []))
+        stage.deps = dependency.loadd_from(
+            stage, d.get(Stage.PARAM_DEPS) or []
+        )
+        stage.outs = output.loadd_from(stage, d.get(Stage.PARAM_OUTS) or [])
 
         return stage
 
