@@ -4,15 +4,14 @@ import logging
 import os
 import re
 import sqlite3
+from urllib.parse import urlunparse, urlencode
 
 from dvc.config import Config
 from dvc.exceptions import DvcException
 from dvc.utils import current_timestamp
 from dvc.utils import relpath
 from dvc.utils import to_chunks
-from dvc.utils.compat import fspath_py35
-from dvc.utils.compat import urlencode
-from dvc.utils.compat import urlunparse
+from dvc.compat import fspath_py35
 from dvc.utils.fs import get_inode
 from dvc.utils.fs import get_mtime_and_size
 from dvc.utils.fs import remove
@@ -27,7 +26,7 @@ class StateVersionTooNewError(DvcException):
     """Thrown when dvc version is older than the state database version."""
 
     def __init__(self, dvc_version, expected, actual):
-        super(StateVersionTooNewError, self).__init__(
+        super().__init__(
             "you are using an old version '{dvc_version}' of dvc that is "
             "using state file version '{expected}' which is not compatible "
             "with the state file version '{actual}' that is used in this "
@@ -430,14 +429,13 @@ class State(object):  # pylint: disable=too-many-instance-attributes
             path_info (dict): path info to add to the list of links.
         """
         assert path_info.scheme == "local"
-        path = fspath_py35(path_info)
 
-        if not os.path.exists(path):
+        if not os.path.exists(fspath_py35(path_info)):
             return
 
-        mtime, _ = get_mtime_and_size(path, self.repo.tree)
-        inode = get_inode(path)
-        relative_path = relpath(path, self.root_dir)
+        mtime, _ = get_mtime_and_size(path_info, self.repo.tree)
+        inode = get_inode(path_info)
+        relative_path = relpath(path_info, self.root_dir)
 
         cmd = "REPLACE INTO {}(path, inode, mtime) " "VALUES (?, ?, ?)".format(
             self.LINK_STATE_TABLE
