@@ -15,11 +15,7 @@ import nanotime
 from ruamel.yaml import YAML
 from shortuuid import uuid
 
-from dvc.utils.compat import cast_bytes_py2
-from dvc.utils.compat import fspath
-from dvc.utils.compat import fspath_py35
-from dvc.utils.compat import makedirs as _makedirs
-from dvc.utils.compat import open
+from dvc.compat import fspath, fspath_py35
 
 
 logger = logging.getLogger(__name__)
@@ -109,53 +105,6 @@ def dict_md5(d, exclude=()):
     return bytes_md5(byts)
 
 
-def copyfile(src, dest, no_progress_bar=False, name=None):
-    """Copy file with progress bar"""
-    from dvc.exceptions import DvcException
-    from dvc.progress import Tqdm
-    from dvc.system import System
-
-    src = fspath_py35(src)
-    dest = fspath_py35(dest)
-
-    name = name if name else os.path.basename(dest)
-    total = os.stat(src).st_size
-
-    if os.path.isdir(dest):
-        dest = os.path.join(dest, os.path.basename(src))
-
-    try:
-        System.reflink(src, dest)
-    except DvcException:
-        with Tqdm(
-            desc=name, disable=no_progress_bar, total=total, bytes=True
-        ) as pbar:
-            with open(src, "rb") as fsrc, open(dest, "wb+") as fdest:
-                while True:
-                    buf = fsrc.read(LOCAL_CHUNK_SIZE)
-                    if not buf:
-                        break
-                    fdest.write(buf)
-                    pbar.update(len(buf))
-
-
-def makedirs(path, exist_ok=False, mode=None):
-    path = fspath_py35(path)
-
-    if mode is None:
-        _makedirs(path, exist_ok=exist_ok)
-        return
-
-    # utilize umask to set proper permissions since Python 3.7 the `mode`
-    # `makedirs` argument no longer affects the file permission bits of
-    # newly-created intermediate-level directories.
-    umask = os.umask(0o777 - mode)
-    try:
-        _makedirs(path, exist_ok=exist_ok)
-    finally:
-        os.umask(umask)
-
-
 def _split(list_to_split, chunk_size):
     return [
         list_to_split[i : i + chunk_size]
@@ -205,8 +154,7 @@ def fix_env(env=None):
         lp_key = "LD_LIBRARY_PATH"
         lp_orig = env.get(lp_key + "_ORIG", None)
         if lp_orig is not None:
-            # NOTE: py2 doesn't like unicode strings in environ
-            env[cast_bytes_py2(lp_key)] = cast_bytes_py2(lp_orig)
+            env[lp_key] = lp_orig
         else:
             env.pop(lp_key, None)
 
@@ -283,12 +231,6 @@ def to_yaml_string(data):
     return stream.getvalue()
 
 
-def walk_files(directory):
-    for root, _, files in os.walk(fspath(directory)):
-        for f in files:
-            yield os.path.join(root, f)
-
-
 def colorize(message, color=None):
     """Returns a message in a specified color."""
     if not color:
@@ -392,7 +334,7 @@ def env2bool(var, undefined=False):
 
 
 def resolve_output(inp, out):
-    from dvc.utils.compat import urlparse
+    from urllib.parse import urlparse
 
     name = os.path.basename(urlparse(inp).path)
     if not out:
